import { jsx as _jsx } from "react/jsx-runtime";
import { useChartData } from '../../context/ChartContext';
import { useScaleChecked } from '../../context/ScaleContext';
import { useHighlight } from '../../highlight';
function BaseLineZones() {
    const { toolOptions: { selectedTool, data: { baselineCorrection }, }, } = useChartData();
    const baseLineZones = baselineCorrection.zones;
    if (selectedTool !== 'baselineCorrection' || baseLineZones.length === 0) {
        return null;
    }
    return (_jsx("g", { children: baselineCorrection.zones.map((zone) => (_jsx(BaseLineZone, { ...zone }, zone.id))) }));
}
function BaseLineZone(props) {
    const { from, to, id } = props;
    const { onHover, isActive, defaultActiveStyle: { backgroundColor: activeFill }, } = useHighlight([id], { type: 'BASELINE_ZONE', extra: { id } });
    const { scaleX } = useScaleChecked();
    const x = scaleX()(to);
    const width = scaleX()(from) - scaleX()(to);
    return (_jsx("g", { transform: `translate(${x},0)`, ...onHover, children: _jsx("rect", { x: "0", width: width, height: "100%", style: { backgroundColor: 'red' }, fill: isActive ? activeFill : '#b8b8b857' }) }));
}
export default BaseLineZones;
