import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useState, } from 'react';
const defaultKeyModifiersState = {
    ctrlKey: false,
    shiftKey: false,
    altKey: false,
};
export const KeyModifierContext = createContext(defaultKeyModifiersState);
export function useKeyModifiers() {
    const context = useContext(KeyModifierContext);
    if (!context) {
        throw new Error('key modifiers context was not found');
    }
    return context;
}
const isMac = navigator !== undefined && navigator.userAgent.toLowerCase().includes('mac');
export function getModifiers(event) {
    const { shiftKey, altKey, metaKey } = event;
    const ctrlKey = isMac ? metaKey : event.ctrlKey;
    return { ctrlKey, shiftKey, altKey };
}
export function KeyModifiersProvider({ children }) {
    const [modifiers, setModifiers] = useState(defaultKeyModifiersState);
    useEffect(() => {
        function handleKeyDown(event) {
            setModifiers(getModifiers(event));
        }
        function handleKeyUp(event) {
            setModifiers(getModifiers(event));
        }
        document.addEventListener('keydown', handleKeyDown);
        document.addEventListener('keyup', handleKeyUp);
        return () => {
            document.removeEventListener('keydown', handleKeyDown);
            document.removeEventListener('keyup', handleKeyUp);
        };
    }, []);
    return (_jsx(KeyModifierContext.Provider, { value: modifiers, children: children }));
}
