import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { Formik } from 'formik';
import { useCallback, useRef } from 'react';
import * as yup from 'yup';
import { useDispatch } from '../context/DispatchContext';
import Button from '../elements/Button';
import CloseButton from '../elements/CloseButton';
import FormikTextarea from '../elements/formik/FormikTextarea';
import { useAlert } from '../elements/popup/Alert';
import { ModalStyles } from './ModalStyle';
const styles = css `
  width: 600px;
  height: 300px;

  .inner-content {
    flex: 1;
    border: none;
    overflow: hidden;
    padding: 0;
  }

  .text-area {
    width: 100%;
    height: 100%;
    outline: none;
    resize: none;
    padding: 0 0 0 15px;
  }
`;
const validationSchema = yup.object({
    publicationText: yup.string().required(),
});
function ImportPublicationStringModal({ onClose, }) {
    const formRef = useRef();
    const dispatch = useDispatch();
    const alert = useAlert();
    const publicationStringHandler = useCallback((values) => {
        void (async () => {
            const hideLoading = await alert.showLoading('Generate spectrum from publication string in progress');
            setTimeout(() => {
                dispatch({
                    type: 'GENERATE_SPECTRUM_FROM_PUBLICATION_STRING',
                    payload: values,
                });
                hideLoading();
            });
            onClose();
        })();
    }, [alert, dispatch, onClose]);
    return (_jsxs("div", { css: [ModalStyles, styles], children: [_jsxs("div", { className: "header handle", children: [_jsx("span", { children: "Import from publication string" }), _jsx(CloseButton, { onClick: onClose, className: "close-bt" })] }), _jsx("div", { className: "inner-content", children: _jsx(Formik, { innerRef: formRef, initialValues: {
                        publicationText: '1H NMR (CDCl3, 400MHz) δ 10.58 (b, 1H), 7.40 (d, 1H, J = 8.0 Hz), 6.19 (d, 1H, J = 7.6 Hz), 4.88 (s, 1H), 2.17 (s, 3H), 1.02 (s, 9H), 1.01 (s, 9H), 0.89 (s, 9H)',
                    }, validationSchema: validationSchema, onSubmit: publicationStringHandler, children: _jsx(FormikTextarea, { name: "publicationText", className: "text-area", placeholder: "Enter publication string" }) }) }), _jsx("div", { className: "footer-container", children: _jsx(Button.Done, { onClick: () => formRef.current.submitForm(), children: "Import" }) })] }));
}
export default ImportPublicationStringModal;
