import { jsx as _jsx } from "react/jsx-runtime";
import { Formik } from 'formik';
import { useImperativeHandle, useRef, memo, forwardRef, useCallback, useMemo, } from 'react';
import { useChartData } from '../../context/ChartContext';
import { usePreferences } from '../../context/PreferencesContext';
import { Scroller } from '../../elements/Scroller';
import useNucleus from '../../hooks/useNucleus';
import { usePanelPreferencesByNuclei } from '../../hooks/usePanelPreferences';
import { convertPathArrayToString } from '../../utility/convertPathArrayToString';
import { getSpectraObjectPaths } from '../../utility/getSpectraObjectPaths';
import { NucleusGroup } from '../extra/preferences/NucleusGroup';
import { PreferencesContainer } from '../extra/preferences/PreferencesContainer';
import { SpectraColumnsManager } from './base/SpectraColumnsManager';
function SpectraPreferences(props, ref) {
    const formRef = useRef(null);
    const { data, view: { spectra: { activeTab }, }, } = useChartData();
    const preferences = usePreferences();
    const nuclei = useNucleus();
    const preferencesByNuclei = usePanelPreferencesByNuclei('spectra', nuclei);
    const { datalist, paths } = useMemo(() => getSpectraObjectPaths(data), [data]);
    function saveHandler(values) {
        preferences.dispatch({
            type: 'SET_PANELS_PREFERENCES',
            payload: { key: 'spectra', value: values },
        });
    }
    useImperativeHandle(ref, () => ({
        saveSetting: () => {
            formRef.current.submitForm();
        },
    }), []);
    const handleAdd = useCallback((nucleus, index) => {
        const data = formRef.current.values;
        let columns = data.nuclei[nucleus]?.columns || [];
        columns = [
            ...columns.slice(0, index),
            {
                jpath: [],
                label: '',
                visible: true,
            },
            ...columns.slice(index),
        ];
        formRef.current.setValues({
            ...data,
            nuclei: {
                ...data.nuclei,
                [nucleus]: {
                    ...data[nucleus],
                    columns,
                },
            },
        });
    }, []);
    const handleDelete = useCallback((nucleus, index) => {
        const data = formRef.current.values;
        const columns = data.nuclei[nucleus]?.columns.filter((_, columnIndex) => columnIndex !== index);
        formRef.current.setValues({
            ...data,
            nuclei: {
                ...data.nuclei,
                [nucleus]: {
                    ...data[nucleus],
                    columns,
                },
            },
        });
    }, []);
    const mapOnChangeValueHandler = useCallback((key) => paths?.[key] || key, [paths]);
    const mapValue = useCallback((value) => convertPathArrayToString(value), []);
    return (_jsx(PreferencesContainer, { children: _jsx(Formik, { innerRef: formRef, onSubmit: saveHandler, initialValues: preferencesByNuclei, children: _jsx(Scroller, { scrollTo: activeTab, children: nuclei?.map((n) => (_jsx(Scroller.Item, { elementKey: n, children: _jsx(NucleusGroup, { nucleus: n, children: _jsx(SpectraColumnsManager, { nucleus: n, onAdd: handleAdd, onDelete: handleDelete, mapOnChangeValue: mapOnChangeValueHandler, mapValue: mapValue, datalist: datalist }) }) }, n))) }) }) }));
}
export default memo(forwardRef(SpectraPreferences));
